Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Ultimaker/Cura.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Cura/gui/configWizard.py76
-rw-r--r--Cura/util/profile.py1
-rw-r--r--Cura/util/sliceEngine.py1
-rw-r--r--changelog56
-rwxr-xr-xpackage.sh2
5 files changed, 54 insertions, 82 deletions
diff --git a/Cura/util/profile.py b/Cura/util/profile.py
index 2cc65c4d56..4b78131a39 100644
--- a/Cura/util/profile.py
+++ b/Cura/util/profile.py
@@ -213,6 +213,7 @@ setting('overlap_dual', 0.15, float, 'advanced', _('Quality')).setLa
setting('travel_speed', 150.0, float, 'advanced', _('Speed')).setRange(0.1).setLabel(_("Travel speed (mm/s)"), _("Speed at which travel moves are done. A higher value will provide faster print times. Beware that too fast of a speed can reduce print reliability. Most high quality printers can handle 150mm/s to 200mm/s with no problems."))
setting('bottom_layer_speed', 20, float, 'advanced', _('Speed')).setRange(0.1).setLabel(_("Bottom layer speed (mm/s)"), _("Print speed for the bottom layer. It is generally best to print the first layer slower so it sticks better to the printer bed."))
setting('infill_speed', 0.0, float, 'advanced', _('Speed')).setRange(0.0).setLabel(_("Infill speed (mm/s)"), _("Speed at which infill parts are printed. If set to 0 then the print speed is used for the infill. Printing the infill faster can greatly reduce printing time, but this can negatively affect print quality if made too fast."))
+setting('solidarea_speed', 0.0, float, 'advanced', _('Speed')).setRange(0.0).setLabel(_("Top/bottom speed (mm/s)"), _("Speed at which top/bottom parts are printed. If set to 0 then the print speed is used for the infill. Printing the top/bottom faster can greatly reduce printing time, but this can negatively affect print quality."))
setting('inset0_speed', 0.0, float, 'advanced', _('Speed')).setRange(0.0).setLabel(_("Outer shell speed (mm/s)"), _("Speed at which outer shell is printed. If set to 0 then the print speed is used. Printing the outer shell at a lower speed improves the final skin quality. However, having a large difference between the inner shell speed and the outer shell speed will effect quality in a negative way."))
setting('insetx_speed', 0.0, float, 'advanced', _('Speed')).setRange(0.0).setLabel(_("Inner shell speed (mm/s)"), _("Speed at which inner shells are printed. If set to 0 then the print speed is used. Printing the inner shell faster then the outer shell will reduce printing time. It is good to set this somewhere in between the outer shell speed and the infill/printing speed."))
setting('cool_min_layer_time', 5, float, 'advanced', _('Cool')).setRange(0).setLabel(_("Minimal layer time (sec)"), _("Minimum time spent in a layer, gives the layer time to cool down before the next layer is put on top. If the layer will be placed down too fast the printer will slow down to make sure it has spent at least this amount of seconds printing this layer."))
diff --git a/Cura/util/sliceEngine.py b/Cura/util/sliceEngine.py
index 73d0189416..8dea90a9eb 100644
--- a/Cura/util/sliceEngine.py
+++ b/Cura/util/sliceEngine.py
@@ -475,6 +475,7 @@ class Engine(object):
'infillSpeed': int(profile.getProfileSettingFloat('infill_speed')) if int(profile.getProfileSettingFloat('infill_speed')) > 0 else int(profile.getProfileSettingFloat('print_speed')),
'inset0Speed': int(profile.getProfileSettingFloat('inset0_speed')) if int(profile.getProfileSettingFloat('inset0_speed')) > 0 else int(profile.getProfileSettingFloat('print_speed')),
'insetXSpeed': int(profile.getProfileSettingFloat('insetx_speed')) if int(profile.getProfileSettingFloat('insetx_speed')) > 0 else int(profile.getProfileSettingFloat('print_speed')),
+ 'skinSpeed': int(profile.getProfileSettingFloat('solidarea_speed')) if int(profile.getProfileSettingFloat('solidarea_speed')) > 0 else int(profile.getProfileSettingFloat('print_speed')),
'moveSpeed': int(profile.getProfileSettingFloat('travel_speed')),
'fanSpeedMin': int(profile.getProfileSettingFloat('fan_speed')) if profile.getProfileSetting('fan_enabled') == 'True' else 0,
'fanSpeedMax': int(profile.getProfileSettingFloat('fan_speed_max')) if profile.getProfileSetting('fan_enabled') == 'True' else 0,
diff --git a/changelog b/changelog
deleted file mode 100644
index ffad1f19c8..0000000000
--- a/changelog
+++ /dev/null
@@ -1,56 +0,0 @@
-Development
-* Added an expert parameter for the wipe tower size, and made brim go around the wipe tower
-* Added experimental support for printing with the Doodle3D WiFi box
-* Updated object boundaries for multi-object prints, allows for tighter fitting of objects on the build platform
-* Updated time-estimate to greatly improve accuracy of the estimate.
-* Fixed problem with retractions not happening when they should.
-* Added keyboard control for the 3D window to look around with cursor keys.
-
-Ultimaker2 - Firmware update - 13.12
-* Fixed the problem where aborting a print did not always home the head.
-* Fixed bug in acceleration planning causing slow moves on rare occasions.
-* Disable the normal menus during USB printing, and support for USB based menus.
-* Disable stepper drivers after print is finished or aborted, so you can manually move the head.
-* Expert feature: Support M907 for setting the motor current.
-
-Ultimaker Original - Firmware update - 13.12
-* Fixed bug in acceleration planning causing slow moves on rare occasions.
-* Updated to new ErikZalm Marlin base, fixing the long standing slower retraction bug.
-
-13.11.2
-* Adjusted the gantry height to 55mm for the Ultimaker, as 60mm was 3mm to high for the default setup with an V2 hotend.
-* Added disallowed zones for UM2
-* Added ooze-shield for dual-color printing
-* Added wipe tower for dual-extrusion
-* Added no-go zones for UM2 glass clips
-
-Ultimaker2 - Firmware update - 13.11-2
-* Fixed UM2 build volume offset so that you do not print off the glass plate.
-* Slightly tweaked the filament change procedure so there is less chance of a blob staying behind.
-* Slightly tweaked the SD-Card error problems.
-* Added LED settings to Tune menu
-* Start heating the nozzles when the bed is nearing its final temperature, so the nozzles do not sit hot.
-* Make sure all commands are finished before starting a print or changing material. This could cause issues when you where too fast.
-
-13.11
-* Added imageToMesh tool to load images as 3D height maps
-* Fixed Z support distance when using "everywhere" support.
-* Updated to new version of clipper to fix rare slicing bugs that resulted in odd paths.
-* Fixed "Reset profile" so it no longer resets the machine settings.
-* Updated support material so support is smoother and has less small sections which are hard to remove.
-* Fixed start-gcode when using dual-support material
-* Change how the fan is handled on lower layer to improve UM2 printing.
-* Fix that retraction is enabled when selecting UM2 or RepRap.
-* Scale down very large models, or scale up very tiny models automagicly.
-* Fixed skirt and brim to go around the support instead of under it.
-* Added spiralize mode
-
-Ultimaker2 - Firmware update - 13.10-5
-* Fixed SD-Card read error
-* Added feature to store your own material presets
-* Fixed the 280C ABS problem, causing a temperature sensor error
-
-13.10
-* Added YouMagine upload button
-* Added multiple machine support
-* Redone support material
diff --git a/package.sh b/package.sh
index 17a06cdb7d..c9b82dcd8d 100755
--- a/package.sh
+++ b/package.sh
@@ -19,7 +19,7 @@ BUILD_TARGET=${1:-none}
##Do we need to create the final archive
ARCHIVE_FOR_DISTRIBUTION=1
##Which version name are we appending to the final archive
-export BUILD_NAME=15.01-RC2
+export BUILD_NAME=15.01-RC3
TARGET_DIR=Cura-${BUILD_NAME}-${BUILD_TARGET}
##Revision
diff --git a/Cura/gui/configWizard.py b/Cura/gui/configWizard.py
index 6f0daeeb23..dfa1e003f4 100644
--- a/Cura/gui/configWizard.py
+++ b/Cura/gui/configWizard.py
@@ -227,25 +227,25 @@ class InfoPage(wx.wizard.WizardPageSimple):
class PrintrbotPage(InfoPage):
def __init__(self, parent):
self._printer_info = [
- # X, Y, Z, Filament Diameter, PrintTemperature, Print Speed, Travel Speed, Retract speed, Retract amount
- ("Simple Metal", 150, 150, 150, 1.75, 208, 40, 70, 30, 1),
- ("Metal Plus", 250, 250, 250, 1.75, 208, 40, 70, 30, 1),
- ("Simple Makers Kit", 100, 100, 100, 1.75, 208, 40, 70, 30, 1),
+ # X, Y, Z, Nozzle Size, Filament Diameter, PrintTemperature, Print Speed, Travel Speed, Retract speed, Retract amount, use bed level sensor
+ ("Simple Metal", 150, 150, 150, 0.4, 1.75, 208, 40, 70, 30, 1, True),
+ ("Metal Plus", 250, 250, 250, 0.4, 1.75, 208, 40, 70, 30, 1, True),
+ ("Simple Makers Kit", 100, 100, 100, 0.4, 1.75, 208, 40, 70, 30, 1, True),
(":" + _("Older models"),),
- ("Original", 130, 130, 130, 2.95, 208, 40, 70, 30, 1),
- ("Simple Maker's Edition v1", 100, 100, 100, 1.75, 208, 40, 70, 30, 1),
- ("Simple Maker's Edition v2 (2013 Printrbot Simple)", 100, 100, 100, 1.75, 208, 40, 70, 30, 1),
- ("Simple Maker's Edition v3 (2014 Printrbot Simple)", 100, 100, 100, 1.75, 208, 40, 70, 30, 1),
- ("Simple Maker's Edition v4 (Model 1405)", 100, 100, 100, 1.75, 208, 40, 70, 30, 1),
- ("Jr v1", 150, 100, 80, 1.75, 208, 40, 70, 30, 1),
- ("Jr v2", 150, 150, 150, 1.75, 208, 40, 70, 30, 1),
- ("LC v2", 150, 150, 150, 1.75, 208, 40, 70, 30, 1),
- ("Plus v2", 200, 200, 200, 1.75, 208, 40, 70, 30, 1),
- ("Plus v2.1", 200, 200, 200, 1.75, 208, 40, 70, 30, 1),
- ("Plus v2.2 (Model 1404/140422)", 250, 250, 250, 1.75, 208, 40, 70, 30, 1),
- ("Plus v2.3 (Model 140501)", 250, 250, 250, 1.75, 208, 40, 70, 30, 1),
- ("Plus v2.4 (Model 140507)", 250, 250, 250, 1.75, 208, 40, 70, 30, 1),
- ("Go v2 Large", 609, 305, 305, 1.75, 208, 35, 70, 30, 1),
+ ("Original", 130, 130, 130, 0.5, 2.95, 208, 40, 70, 30, 1, False),
+ ("Simple Maker's Edition v1", 100, 100, 100, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Simple Maker's Edition v2 (2013 Printrbot Simple)", 100, 100, 100, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Simple Maker's Edition v3 (2014 Printrbot Simple)", 100, 100, 100, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Simple Maker's Edition v4 (Model 1405)", 100, 100, 100, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Jr v1", 150, 100, 80, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Jr v2", 150, 150, 150, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("LC v2", 150, 150, 150, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Plus v2", 200, 200, 200, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Plus v2.1", 200, 200, 200, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Plus v2.2 (Model 1404/140422)", 250, 250, 250, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Plus v2.3 (Model 140501)", 250, 250, 250, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Plus v2.4 (Model 140507)", 250, 250, 250, 0.5, 1.75, 208, 40, 70, 30, 1, False),
+ ("Go v2 Large", 609, 305, 305, 0.5, 1.75, 208, 35, 70, 30, 1, False),
]
super(PrintrbotPage, self).__init__(parent, _("Printrbot Selection"))
@@ -270,13 +270,13 @@ class PrintrbotPage(InfoPage):
profile.putMachineSetting('machine_width', data[0])
profile.putMachineSetting('machine_depth', data[1])
profile.putMachineSetting('machine_height', data[2])
- profile.putProfileSetting('nozzle_size', '0.5')
- profile.putProfileSetting('filament_diameter', data[3])
- profile.putProfileSetting('print_temperature', data[4])
- profile.putProfileSetting('print_speed', data[5])
- profile.putProfileSetting('travel_speed', data[6])
- profile.putProfileSetting('retraction_speed', data[7])
- profile.putProfileSetting('retraction_amount', data[8])
+ profile.putProfileSetting('nozzle_size', data[3])
+ profile.putProfileSetting('filament_diameter', data[4])
+ profile.putProfileSetting('print_temperature', data[5])
+ profile.putProfileSetting('print_speed', data[6])
+ profile.putProfileSetting('travel_speed', data[7])
+ profile.putProfileSetting('retraction_speed', data[8])
+ profile.putProfileSetting('retraction_amount', data[9])
profile.putProfileSetting('wall_thickness', float(profile.getProfileSettingFloat('nozzle_size')) * 2)
profile.putMachineSetting('has_heated_bed', 'False')
profile.putMachineSetting('machine_center_is_zero', 'False')
@@ -285,6 +285,32 @@ class PrintrbotPage(InfoPage):
profile.putMachineSetting('extruder_head_size_max_x', '0')
profile.putMachineSetting('extruder_head_size_max_y', '0')
profile.putMachineSetting('extruder_head_size_height', '0')
+ if data[10]:
+ profile.setAlterationFile('start.gcode', """;Sliced at: {day} {date} {time}
+;Basic settings: Layer height: {layer_height} Walls: {wall_thickness} Fill: {fill_density}
+;Print time: {print_time}
+;Filament used: {filament_amount}m {filament_weight}g
+;Filament cost: {filament_cost}
+;M190 S{print_bed_temperature} ;Uncomment to add your own bed temperature line
+;M109 S{print_temperature} ;Uncomment to add your own temperature line
+G21 ;metric values
+G90 ;absolute positioning
+M82 ;set extruder to absolute mode
+M107 ;start with the fan off
+
+G28 X0 Y0 ;move X/Y to min endstops
+G28 Z0 ;move Z to min endstops
+G29 ;Run the auto bed leveling
+
+G1 Z15.0 F{travel_speed} ;move the platform down 15mm
+
+G92 E0 ;zero the extruded length
+G1 F200 E3 ;extrude 3mm of feed stock
+G92 E0 ;zero the extruded length again
+G1 F{travel_speed}
+;Put printing message on LCD screen
+M117 Printing...
+""")
class OtherMachineSelectPage(InfoPage):
def __init__(self, parent):